@@ -44,12 +44,6 @@ DATAGROWTH_DEFAULT_CONFIGURATION = getattr(settings, "DATAGROWTH_DEFAULT_CONFIGU
     "global_purge_immediately": False,  # by default keep resources around
     "global_sample_size": 0,
     "global_cache_only": False,
-    "global_pipeline_app_label": None,
-    "global_pipeline_models": {
-        "document": "Document",
-        "process_result": "ProcessResult",
-        "batch": "Batch"
-    },
 
     "http_resource_continuation_limit": 1,
     "http_resource_interval_duration": 0,  # NB: milliseconds!
@@ -72,6 +66,8 @@ DATAGROWTH_DEFAULT_CONFIGURATION = getattr(settings, "DATAGROWTH_DEFAULT_CONFIGU
     "rank_processor_batch_size": 1000,
     "rank_processor_result_size": 20,
 
+    "extract_processor_extract_from_object_values": False,
+
     "micro_service_connections": {
         "image_recognition": {
             "protocol": "http",
